package com.docus.server.ws;

import com.docus.core.util.Func;
import com.docus.infrastructure.core.exception.BaseException;
import com.docus.server.collect.service.CollectService;
import com.docus.server.collect.service.IParseService;
import com.docus.server.record.pojo.entity.MedicalRecord;
import com.docus.server.record.service.IMedicalRecordService;
import com.docus.server.sys.common.pojo.dto.DeptDTO;
import com.docus.server.sys.service.IPowerDeptService;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.HashMap;
import java.util.Map;

@Slf4j
@Component
public class WsCollect {
    @Autowired
    private IMedicalRecordService medicalRecordService;
    @Autowired
    private IParseService parseService;
    @Autowired
    private CollectService collectService;
    @Autowired
    private IWsResult wsResult;
    @Autowired
    private IPowerDeptService powerDeptService;
    @Autowired
    private IWsResult wsResult;
    @Autowired
    private IWsResult wsResult;

    //接收xml。并且下载病案。
    public String receiveHandNumbness(String handNumbness) {
        log.info("收到手麻消息：{}", handNumbness);
        try {
            MedicalRecord medicalRecord = parseService.parseHandNumbness(handNumbness);
            medicalRecordService.receive(medicalRecord);
            return wsResult.ok(medicalRecord.getParams());
        } catch (Exception e) {
            return wsResult.fail(e.getMessage());
        }
    }

    public String receiveDept(String deptXml) {
        log.info("收到科室消息：{}", deptXml);
        try {
            DeptDTO dept = parseService.parseDeptXml(deptXml);

            //此处需要存储原xml内容。
            collectService.receiveDept(dept);
            return wsResult.ok(dept.getParams());
        } catch (Exception e) {
            return wsResult.fail(e.getMessage(), dept.getParams());
        }
    }


    public String deptModify(String receiveUser) {
        log.info("新增/修改科室数据：{}", receiveUser);
        DeptDTO deptDto = new DeptDTO();
        try {
            deptDto = parseService.parseDeptXml(receiveUser);
            String operateType = deptDto.getOperateType();
            String delType = "D";
            // 判断操作类型
            if (Func.isNotEmpty(operateType) && operateType.contains(delType)) {
                powerDeptService.delDeptByDeptCode(deptDto.getDeptCode());
            } else {
                powerDeptService.saveOrUpdatePowerDept(deptDto);
            }
            return wsResult.ok(parseService.parseDeptOkXml(deptDto));
        } catch (BaseException e) {
            log.error(e.getMessage(), e);
            deptDto.setErrorMsg(e.getMessage());
            return wsResult.fail(parseService.parseDeptFailXml(deptDto));
        } catch (Exception e) {
            log.error(e.getMessage(), e);
            deptDto.setErrorMsg("系统出错啦！");
            return wsResult.fail(parseService.parseDeptFailXml(deptDto));
        }
    }


}
